// Code generated by smithy-go-codegen DO NOT EDIT.

package autoscalingplans

import (
	"context"
	awsmiddleware "github.com/aws/aws-sdk-go-v2/aws/middleware"
	"github.com/aws/aws-sdk-go-v2/aws/signer/v4"
	"github.com/aws/aws-sdk-go-v2/service/autoscalingplans/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Retrieves the forecast data for a scalable resource. Capacity forecasts are
// represented as predicted values, or data points, that are calculated using
// historical data points from a specified CloudWatch load metric. Data points are
// available for up to 56 days.
func (c *Client) GetScalingPlanResourceForecastData(ctx context.Context, params *GetScalingPlanResourceForecastDataInput, optFns ...func(*Options)) (*GetScalingPlanResourceForecastDataOutput, error) {
	if params == nil {
		params = &GetScalingPlanResourceForecastDataInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetScalingPlanResourceForecastData", params, optFns, addOperationGetScalingPlanResourceForecastDataMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetScalingPlanResourceForecastDataOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetScalingPlanResourceForecastDataInput struct {

	// The exclusive end time of the time range for the forecast data to get. The
	// maximum time duration between the start and end time is seven days. Although
	// this parameter can accept a date and time that is more than two days in the
	// future, the availability of forecast data has limits. AWS Auto Scaling only
	// issues forecasts for periods of two days in advance.
	//
	// This member is required.
	EndTime *time.Time

	// The type of forecast data to get.
	//
	// * LoadForecast: The load metric forecast.
	//
	// *
	// CapacityForecast: The capacity forecast.
	//
	// * ScheduledActionMinCapacity: The
	// minimum capacity for each scheduled scaling action. This data is calculated as
	// the larger of two values: the capacity forecast or the minimum capacity in the
	// scaling instruction.
	//
	// * ScheduledActionMaxCapacity: The maximum capacity for
	// each scheduled scaling action. The calculation used is determined by the
	// predictive scaling maximum capacity behavior setting in the scaling instruction.
	//
	// This member is required.
	ForecastDataType types.ForecastDataType

	// The ID of the resource. This string consists of the resource type and unique
	// identifier.
	//
	// * Auto Scaling group - The resource type is autoScalingGroup and
	// the unique identifier is the name of the Auto Scaling group. Example:
	// autoScalingGroup/my-asg.
	//
	// * ECS service - The resource type is service and the
	// unique identifier is the cluster name and service name. Example:
	// service/default/sample-webapp.
	//
	// * Spot Fleet request - The resource type is
	// spot-fleet-request and the unique identifier is the Spot Fleet request ID.
	// Example: spot-fleet-request/sfr-73fbd2ce-aa30-494c-8788-1cee4EXAMPLE.
	//
	// *
	// DynamoDB table - The resource type is table and the unique identifier is the
	// resource ID. Example: table/my-table.
	//
	// * DynamoDB global secondary index - The
	// resource type is index and the unique identifier is the resource ID. Example:
	// table/my-table/index/my-table-index.
	//
	// * Aurora DB cluster - The resource type is
	// cluster and the unique identifier is the cluster name. Example:
	// cluster:my-db-cluster.
	//
	// This member is required.
	ResourceId *string

	// The scalable dimension for the resource.
	//
	// This member is required.
	ScalableDimension types.ScalableDimension

	// The name of the scaling plan.
	//
	// This member is required.
	ScalingPlanName *string

	// The version number of the scaling plan.
	//
	// This member is required.
	ScalingPlanVersion *int64

	// The namespace of the AWS service.
	//
	// This member is required.
	ServiceNamespace types.ServiceNamespace

	// The inclusive start time of the time range for the forecast data to get. The
	// date and time can be at most 56 days before the current date and time.
	//
	// This member is required.
	StartTime *time.Time
}

type GetScalingPlanResourceForecastDataOutput struct {

	// The data points to return.
	//
	// This member is required.
	Datapoints []types.Datapoint

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata
}

func addOperationGetScalingPlanResourceForecastDataMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpGetScalingPlanResourceForecastData{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpGetScalingPlanResourceForecastData{}, middleware.After)
	if err != nil {
		return err
	}
	if err = addSetLoggerMiddleware(stack, options); err != nil {
		return err
	}
	if err = awsmiddleware.AddClientRequestIDMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddComputeContentLengthMiddleware(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = v4.AddComputePayloadSHA256Middleware(stack); err != nil {
		return err
	}
	if err = addRetryMiddlewares(stack, options); err != nil {
		return err
	}
	if err = addHTTPSignerV4Middleware(stack, options); err != nil {
		return err
	}
	if err = awsmiddleware.AddAttemptClockSkewMiddleware(stack); err != nil {
		return err
	}
	if err = addClientUserAgent(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addOpGetScalingPlanResourceForecastDataValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware_opGetScalingPlanResourceForecastData(options.Region), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	return nil
}

func newServiceMetadataMiddleware_opGetScalingPlanResourceForecastData(region string) *awsmiddleware.RegisterServiceMetadata {
	return &awsmiddleware.RegisterServiceMetadata{
		Region:        region,
		ServiceID:     ServiceID,
		SigningName:   "autoscaling-plans",
		OperationName: "GetScalingPlanResourceForecastData",
	}
}
