// Code generated by smithy-go-codegen DO NOT EDIT.

package types

import (
	"time"
)

// The filters applied to datastore query.
type DatastoreFilter struct {

	// A filter that allows the user to set cutoff dates for records. All datastores
	// created after the specified date will be included in the results.
	CreatedAfter *time.Time

	// A filter that allows the user to set cutoff dates for records. All datastores
	// created before the specified date will be included in the results.
	CreatedBefore *time.Time

	// Allows the user to filter datastore results by name.
	DatastoreName *string

	// Allows the user to filter datastore results by status.
	DatastoreStatus DatastoreStatus
}

// Displays the properties of the datastore, including the ID, Arn, name, and the
// status of the datastore.
type DatastoreProperties struct {

	// The Amazon Resource Name used in the creation of the datastore.
	//
	// This member is required.
	DatastoreArn *string

	// The AWS endpoint for the datastore. Each datastore will have it's own endpoint
	// with datastore ID in the endpoint URL.
	//
	// This member is required.
	DatastoreEndpoint *string

	// The AWS-generated ID number for the datastore.
	//
	// This member is required.
	DatastoreId *string

	// The status of the datastore. Possible statuses are 'CREATING', 'ACTIVE',
	// 'DELETING', or 'DELETED'.
	//
	// This member is required.
	DatastoreStatus DatastoreStatus

	// The FHIR version. Only R4 version data is supported.
	//
	// This member is required.
	DatastoreTypeVersion FHIRVersion

	// The time that a datastore was created.
	CreatedAt *time.Time

	// The user-generated name for the datastore.
	DatastoreName *string

	// The preloaded data configuration for the datastore. Only data preloaded from
	// Synthea is supported.
	PreloadDataConfig *PreloadDataConfig
}

// Displays the properties of the import job, including the ID, Arn, Name, and the
// status of the datastore.
type ImportJobProperties struct {

	// The datastore id used when the Import job was created.
	//
	// This member is required.
	DatastoreId *string

	// The input data configuration that was supplied when the Import job was created.
	//
	// This member is required.
	InputDataConfig InputDataConfig

	// The AWS-generated id number for the Import job.
	//
	// This member is required.
	JobId *string

	// The job status for an Import job. Possible statuses are SUBMITTED, IN_PROGRESS,
	// COMPLETED, FAILED.
	//
	// This member is required.
	JobStatus JobStatus

	// The time that the Import job was submitted for processing.
	//
	// This member is required.
	SubmitTime *time.Time

	// The Amazon Resource Name (ARN) that gives Amazon HealthLake access to your input
	// data.
	DataAccessRoleArn *string

	// The time that the Import job was completed.
	EndTime *time.Time

	// The user-generated name for an Import job.
	JobName *string

	// An explanation of any errors that may have occurred during the FHIR import job.
	Message *string
}

// The input properties for an import job.
//
// The following types satisfy this interface:
//  InputDataConfigMemberS3Uri
type InputDataConfig interface {
	isInputDataConfig()
}

// The S3Uri is the user specified S3 location of the FHIR data to be imported into
// Amazon HealthLake.
type InputDataConfigMemberS3Uri struct {
	Value string
}

func (*InputDataConfigMemberS3Uri) isInputDataConfig() {}

// The input properties for the preloaded datastore. Only data preloaded from
// Synthea is supported.
type PreloadDataConfig struct {

	// The type of preloaded data. Only Synthea preloaded data is supported.
	//
	// This member is required.
	PreloadDataType PreloadDataType
}

// UnknownUnionMember is returned when a union member is returned over the wire,
// but has an unknown tag.
type UnknownUnionMember struct {
	Tag   string
	Value []byte
}

func (*UnknownUnionMember) isInputDataConfig() {}
