// Code generated by smithy-go-codegen DO NOT EDIT.

package types

// The output that you want to add to this flow.
type AddOutputRequest struct {

	// The protocol to use for the output.
	//
	// This member is required.
	Protocol Protocol

	// The range of IP addresses that should be allowed to initiate output requests to
	// this flow. These IP addresses should be in the form of a Classless Inter-Domain
	// Routing (CIDR) block; for example, 10.0.0.0/16.
	CidrAllowList []string

	// A description of the output. This description appears only on the AWS Elemental
	// MediaConnect console and will not be seen by the end user.
	Description *string

	// The IP address from which video will be sent to output destinations.
	Destination *string

	// The type of key used for the encryption. If no keyType is provided, the service
	// will use the default setting (static-key).
	Encryption *Encryption

	// The maximum latency in milliseconds for Zixi-based streams.
	MaxLatency int32

	// The name of the output. This value must be unique within the current flow.
	Name *string

	// The port to use when content is distributed to this output.
	Port int32

	// The remote ID for the Zixi-pull output stream.
	RemoteId *string

	// The smoothing latency in milliseconds for RIST, RTP, and RTP-FEC streams.
	SmoothingLatency int32

	// The stream ID that you want to use for this transport. This parameter applies
	// only to Zixi-based streams.
	StreamId *string

	// The name of the VPC interface attachment to use for this output.
	VpcInterfaceAttachment *VpcInterfaceAttachment
}

// Information about the encryption of the flow.
type Encryption struct {

	// The type of algorithm that is used for the encryption (such as aes128, aes192,
	// or aes256).
	//
	// This member is required.
	Algorithm Algorithm

	// The ARN of the role that you created during setup (when you set up AWS Elemental
	// MediaConnect as a trusted entity).
	//
	// This member is required.
	RoleArn *string

	// A 128-bit, 16-byte hex value represented by a 32-character string, to be used
	// with the key for encrypting content. This parameter is not valid for static key
	// encryption.
	ConstantInitializationVector *string

	// The value of one of the devices that you configured with your digital rights
	// management (DRM) platform key provider. This parameter is required for SPEKE
	// encryption and is not valid for static key encryption.
	DeviceId *string

	// The type of key that is used for the encryption. If no keyType is provided, the
	// service will use the default setting (static-key).
	KeyType KeyType

	// The AWS Region that the API Gateway proxy endpoint was created in. This
	// parameter is required for SPEKE encryption and is not valid for static key
	// encryption.
	Region *string

	// An identifier for the content. The service sends this value to the key server to
	// identify the current endpoint. The resource ID is also known as the content ID.
	// This parameter is required for SPEKE encryption and is not valid for static key
	// encryption.
	ResourceId *string

	// The ARN of the secret that you created in AWS Secrets Manager to store the
	// encryption key. This parameter is required for static key encryption and is not
	// valid for SPEKE encryption.
	SecretArn *string

	// The URL from the API Gateway proxy that you set up to talk to your key server.
	// This parameter is required for SPEKE encryption and is not valid for static key
	// encryption.
	Url *string
}

// The settings for a flow entitlement.
type Entitlement struct {

	// The ARN of the entitlement.
	//
	// This member is required.
	EntitlementArn *string

	// The name of the entitlement.
	//
	// This member is required.
	Name *string

	// The AWS account IDs that you want to share your content with. The receiving
	// accounts (subscribers) will be allowed to create their own flow using your
	// content as the source.
	//
	// This member is required.
	Subscribers []string

	// Percentage from 0-100 of the data transfer cost to be billed to the subscriber.
	DataTransferSubscriberFeePercent int32

	// A description of the entitlement.
	Description *string

	// The type of encryption that will be used on the output that is associated with
	// this entitlement.
	Encryption *Encryption

	// An indication of whether the entitlement is enabled.
	EntitlementStatus EntitlementStatus
}

// The settings for source failover
type FailoverConfig struct {

	// Search window time to look for dash-7 packets
	RecoveryWindow int32

	State State
}

// The settings for a flow, including its source, outputs, and entitlements.
type Flow struct {

	// The Availability Zone that you want to create the flow in. These options are
	// limited to the Availability Zones within the current AWS.
	//
	// This member is required.
	AvailabilityZone *string

	// The entitlements in this flow.
	//
	// This member is required.
	Entitlements []Entitlement

	// The Amazon Resource Name (ARN), a unique identifier for any AWS resource, of the
	// flow.
	//
	// This member is required.
	FlowArn *string

	// The name of the flow.
	//
	// This member is required.
	Name *string

	// The outputs in this flow.
	//
	// This member is required.
	Outputs []Output

	// The settings for the source of the flow.
	//
	// This member is required.
	Source *Source

	// The current status of the flow.
	//
	// This member is required.
	Status Status

	// A description of the flow. This value is not used or seen outside of the current
	// AWS Elemental MediaConnect account.
	Description *string

	// The IP address from which video will be sent to output destinations.
	EgressIp *string

	// The settings for source failover
	SourceFailoverConfig *FailoverConfig

	Sources []Source

	// The VPC Interfaces for this flow.
	VpcInterfaces []VpcInterface
}

// The entitlements that you want to grant on a flow.
type GrantEntitlementRequest struct {

	// The AWS account IDs that you want to share your content with. The receiving
	// accounts (subscribers) will be allowed to create their own flows using your
	// content as the source.
	//
	// This member is required.
	Subscribers []string

	// Percentage from 0-100 of the data transfer cost to be billed to the subscriber.
	DataTransferSubscriberFeePercent int32

	// A description of the entitlement. This description appears only on the AWS
	// Elemental MediaConnect console and will not be seen by the subscriber or end
	// user.
	Description *string

	// The type of encryption that will be used on the output that is associated with
	// this entitlement.
	Encryption *Encryption

	// An indication of whether the new entitlement should be enabled or disabled as
	// soon as it is created. If you don’t specify the entitlementStatus field in your
	// request, MediaConnect sets it to ENABLED.
	EntitlementStatus EntitlementStatus

	// The name of the entitlement. This value must be unique within the current flow.
	Name *string
}

// An entitlement that has been granted to you from other AWS accounts.
type ListedEntitlement struct {

	// The ARN of the entitlement.
	//
	// This member is required.
	EntitlementArn *string

	// The name of the entitlement.
	//
	// This member is required.
	EntitlementName *string

	// Percentage from 0-100 of the data transfer cost to be billed to the subscriber.
	DataTransferSubscriberFeePercent int32
}

// Provides a summary of a flow, including its ARN, Availability Zone, and source
// type.
type ListedFlow struct {

	// The Availability Zone that the flow was created in.
	//
	// This member is required.
	AvailabilityZone *string

	// A description of the flow.
	//
	// This member is required.
	Description *string

	// The ARN of the flow.
	//
	// This member is required.
	FlowArn *string

	// The name of the flow.
	//
	// This member is required.
	Name *string

	// The type of source. This value is either owned (originated somewhere other than
	// an AWS Elemental MediaConnect flow owned by another AWS account) or entitled
	// (originated at an AWS Elemental MediaConnect flow owned by another AWS account).
	//
	// This member is required.
	SourceType SourceType

	// The current status of the flow.
	//
	// This member is required.
	Status Status
}

// Messages that provide the state of the flow.
type Messages struct {

	// A list of errors that might have been generated from processes on this flow.
	//
	// This member is required.
	Errors []string
}

// A savings plan that reserves a certain amount of outbound bandwidth usage at a
// discounted rate each month over a period of time.
type Offering struct {

	// The type of currency that is used for billing. The currencyCode used for all
	// reservations is US dollars.
	//
	// This member is required.
	CurrencyCode *string

	// The length of time that your reservation would be active.
	//
	// This member is required.
	Duration int32

	// The unit of measurement for the duration of the offering.
	//
	// This member is required.
	DurationUnits DurationUnits

	// The Amazon Resource Name (ARN) that MediaConnect assigns to the offering.
	//
	// This member is required.
	OfferingArn *string

	// A description of the offering.
	//
	// This member is required.
	OfferingDescription *string

	// The cost of a single unit. This value, in combination with priceUnits, makes up
	// the rate.
	//
	// This member is required.
	PricePerUnit *string

	// The unit of measurement that is used for billing. This value, in combination
	// with pricePerUnit, makes up the rate.
	//
	// This member is required.
	PriceUnits PriceUnits

	// A definition of the amount of outbound bandwidth that you would be reserving if
	// you purchase the offering.
	//
	// This member is required.
	ResourceSpecification *ResourceSpecification
}

// The settings for an output.
type Output struct {

	// The name of the output. This value must be unique within the current flow.
	//
	// This member is required.
	Name *string

	// The ARN of the output.
	//
	// This member is required.
	OutputArn *string

	// Percentage from 0-100 of the data transfer cost to be billed to the subscriber.
	DataTransferSubscriberFeePercent int32

	// A description of the output.
	Description *string

	// The address where you want to send the output.
	Destination *string

	// The type of key used for the encryption. If no keyType is provided, the service
	// will use the default setting (static-key).
	Encryption *Encryption

	// The ARN of the entitlement on the originator''s flow. This value is relevant
	// only on entitled flows.
	EntitlementArn *string

	// The input ARN of the AWS Elemental MediaLive channel. This parameter is relevant
	// only for outputs that were added by creating a MediaLive input.
	MediaLiveInputArn *string

	// The port to use when content is distributed to this output.
	Port int32

	// Attributes related to the transport stream that are used in the output.
	Transport *Transport

	// The name of the VPC interface attachment to use for this output.
	VpcInterfaceAttachment *VpcInterfaceAttachment
}

// A pricing agreement for a discounted rate for a specific outbound bandwidth that
// your MediaConnect account will use each month over a specific time period. The
// discounted rate in the reservation applies to outbound bandwidth for all flows
// from your account until your account reaches the amount of bandwidth in your
// reservation. If you use more outbound bandwidth than the agreed upon amount in a
// single month, the overage is charged at the on-demand rate.
type Reservation struct {

	// The type of currency that is used for billing. The currencyCode used for your
	// reservation is US dollars.
	//
	// This member is required.
	CurrencyCode *string

	// The length of time that this reservation is active. MediaConnect defines this
	// value in the offering.
	//
	// This member is required.
	Duration int32

	// The unit of measurement for the duration of the reservation. MediaConnect
	// defines this value in the offering.
	//
	// This member is required.
	DurationUnits DurationUnits

	// The day and time that this reservation expires. This value is calculated based
	// on the start date and time that you set and the offering's duration.
	//
	// This member is required.
	End *string

	// The Amazon Resource Name (ARN) that MediaConnect assigns to the offering.
	//
	// This member is required.
	OfferingArn *string

	// A description of the offering. MediaConnect defines this value in the offering.
	//
	// This member is required.
	OfferingDescription *string

	// The cost of a single unit. This value, in combination with priceUnits, makes up
	// the rate. MediaConnect defines this value in the offering.
	//
	// This member is required.
	PricePerUnit *string

	// The unit of measurement that is used for billing. This value, in combination
	// with pricePerUnit, makes up the rate. MediaConnect defines this value in the
	// offering.
	//
	// This member is required.
	PriceUnits PriceUnits

	// The Amazon Resource Name (ARN) that MediaConnect assigns to the reservation when
	// you purchase an offering.
	//
	// This member is required.
	ReservationArn *string

	// The name that you assigned to the reservation when you purchased the offering.
	//
	// This member is required.
	ReservationName *string

	// The status of your reservation.
	//
	// This member is required.
	ReservationState ReservationState

	// A definition of the amount of outbound bandwidth that you would be reserving if
	// you purchase the offering. MediaConnect defines the values that make up the
	// resourceSpecification in the offering.
	//
	// This member is required.
	ResourceSpecification *ResourceSpecification

	// The day and time that the reservation becomes active. You set this value when
	// you purchase the offering.
	//
	// This member is required.
	Start *string
}

// A definition of what is being billed for, including the type and amount.
type ResourceSpecification struct {

	// The type of resource and the unit that is being billed for.
	//
	// This member is required.
	ResourceType ResourceType

	// The amount of outbound bandwidth that is discounted in the offering.
	ReservedBitrate int32
}

// The settings for the source of the flow.
type SetSourceRequest struct {

	// The type of encryption that is used on the content ingested from this source.
	Decryption *Encryption

	// A description for the source. This value is not used or seen outside of the
	// current AWS Elemental MediaConnect account.
	Description *string

	// The ARN of the entitlement that allows you to subscribe to this flow. The
	// entitlement is set by the flow originator, and the ARN is generated as part of
	// the originator's flow.
	EntitlementArn *string

	// The port that the flow will be listening on for incoming content.
	IngestPort int32

	// The smoothing max bitrate for RIST, RTP, and RTP-FEC streams.
	MaxBitrate int32

	// The maximum latency in milliseconds. This parameter applies only to RIST-based
	// and Zixi-based streams.
	MaxLatency int32

	// The name of the source.
	Name *string

	// The protocol that is used by the source.
	Protocol Protocol

	// The stream ID that you want to use for this transport. This parameter applies
	// only to Zixi-based streams.
	StreamId *string

	// The name of the VPC interface to use for this source.
	VpcInterfaceName *string

	// The range of IP addresses that should be allowed to contribute content to your
	// source. These IP addresses should be in the form of a Classless Inter-Domain
	// Routing (CIDR) block; for example, 10.0.0.0/16.
	WhitelistCidr *string
}

// The settings for the source of the flow.
type Source struct {

	// The name of the source.
	//
	// This member is required.
	Name *string

	// The ARN of the source.
	//
	// This member is required.
	SourceArn *string

	// Percentage from 0-100 of the data transfer cost to be billed to the subscriber.
	DataTransferSubscriberFeePercent int32

	// The type of encryption that is used on the content ingested from this source.
	Decryption *Encryption

	// A description for the source. This value is not used or seen outside of the
	// current AWS Elemental MediaConnect account.
	Description *string

	// The ARN of the entitlement that allows you to subscribe to content that comes
	// from another AWS account. The entitlement is set by the content originator and
	// the ARN is generated as part of the originator's flow.
	EntitlementArn *string

	// The IP address that the flow will be listening on for incoming content.
	IngestIp *string

	// The port that the flow will be listening on for incoming content.
	IngestPort int32

	// Attributes related to the transport stream that are used in the source.
	Transport *Transport

	// The name of the VPC Interface this Source is configured with.
	VpcInterfaceName *string

	// The range of IP addresses that should be allowed to contribute content to your
	// source. These IP addresses should be in the form of a Classless Inter-Domain
	// Routing (CIDR) block; for example, 10.0.0.0/16.
	WhitelistCidr *string
}

// Attributes related to the transport stream that are used in a source or output.
type Transport struct {

	// The protocol that is used by the source or output.
	//
	// This member is required.
	Protocol Protocol

	// The range of IP addresses that should be allowed to initiate output requests to
	// this flow. These IP addresses should be in the form of a Classless Inter-Domain
	// Routing (CIDR) block; for example, 10.0.0.0/16.
	CidrAllowList []string

	// The smoothing max bitrate for RIST, RTP, and RTP-FEC streams.
	MaxBitrate int32

	// The maximum latency in milliseconds. This parameter applies only to RIST-based
	// and Zixi-based streams.
	MaxLatency int32

	// The remote ID for the Zixi-pull stream.
	RemoteId *string

	// The smoothing latency in milliseconds for RIST, RTP, and RTP-FEC streams.
	SmoothingLatency int32

	// The stream ID that you want to use for this transport. This parameter applies
	// only to Zixi-based streams.
	StreamId *string
}

// Information about the encryption of the flow.
type UpdateEncryption struct {

	// The type of algorithm that is used for the encryption (such as aes128, aes192,
	// or aes256).
	Algorithm Algorithm

	// A 128-bit, 16-byte hex value represented by a 32-character string, to be used
	// with the key for encrypting content. This parameter is not valid for static key
	// encryption.
	ConstantInitializationVector *string

	// The value of one of the devices that you configured with your digital rights
	// management (DRM) platform key provider. This parameter is required for SPEKE
	// encryption and is not valid for static key encryption.
	DeviceId *string

	// The type of key that is used for the encryption. If no keyType is provided, the
	// service will use the default setting (static-key).
	KeyType KeyType

	// The AWS Region that the API Gateway proxy endpoint was created in. This
	// parameter is required for SPEKE encryption and is not valid for static key
	// encryption.
	Region *string

	// An identifier for the content. The service sends this value to the key server to
	// identify the current endpoint. The resource ID is also known as the content ID.
	// This parameter is required for SPEKE encryption and is not valid for static key
	// encryption.
	ResourceId *string

	// The ARN of the role that you created during setup (when you set up AWS Elemental
	// MediaConnect as a trusted entity).
	RoleArn *string

	// The ARN of the secret that you created in AWS Secrets Manager to store the
	// encryption key. This parameter is required for static key encryption and is not
	// valid for SPEKE encryption.
	SecretArn *string

	// The URL from the API Gateway proxy that you set up to talk to your key server.
	// This parameter is required for SPEKE encryption and is not valid for static key
	// encryption.
	Url *string
}

// The settings for source failover
type UpdateFailoverConfig struct {

	// Recovery window time to look for dash-7 packets
	RecoveryWindow int32

	State State
}

// The settings for a VPC Source.
type VpcInterface struct {

	// Immutable and has to be a unique against other VpcInterfaces in this Flow
	//
	// This member is required.
	Name *string

	// IDs of the network interfaces created in customer's account by MediaConnect.
	//
	// This member is required.
	NetworkInterfaceIds []string

	// Role Arn MediaConnect can assumes to create ENIs in customer's account
	//
	// This member is required.
	RoleArn *string

	// Security Group IDs to be used on ENI.
	//
	// This member is required.
	SecurityGroupIds []string

	// Subnet must be in the AZ of the Flow
	//
	// This member is required.
	SubnetId *string
}

// The settings for attaching a VPC interface to an output.
type VpcInterfaceAttachment struct {

	// The name of the VPC interface to use for this output.
	VpcInterfaceName *string
}

// Desired VPC Interface for a Flow
type VpcInterfaceRequest struct {

	// The name of the VPC Interface. This value must be unique within the current
	// flow.
	//
	// This member is required.
	Name *string

	// Role Arn MediaConnect can assumes to create ENIs in customer's account
	//
	// This member is required.
	RoleArn *string

	// Security Group IDs to be used on ENI.
	//
	// This member is required.
	SecurityGroupIds []string

	// Subnet must be in the AZ of the Flow
	//
	// This member is required.
	SubnetId *string
}
